/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.12
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package FiftyOneDegreesTrieV3;

public class MapStringString {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected MapStringString(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(MapStringString obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        FiftyOneDegreesTrieV3JNI.delete_MapStringString(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public MapStringString() {
    this(FiftyOneDegreesTrieV3JNI.new_MapStringString__SWIG_0(), true);
  }

  public MapStringString(MapStringString arg0) {
    this(FiftyOneDegreesTrieV3JNI.new_MapStringString__SWIG_1(MapStringString.getCPtr(arg0), arg0), true);
  }

  public long size() {
    return FiftyOneDegreesTrieV3JNI.MapStringString_size(swigCPtr, this);
  }

  public boolean empty() {
    return FiftyOneDegreesTrieV3JNI.MapStringString_empty(swigCPtr, this);
  }

  public void clear() {
    FiftyOneDegreesTrieV3JNI.MapStringString_clear(swigCPtr, this);
  }

  public String get(String key) {
    return FiftyOneDegreesTrieV3JNI.MapStringString_get(swigCPtr, this, key);
  }

  public void set(String key, String x) {
    FiftyOneDegreesTrieV3JNI.MapStringString_set(swigCPtr, this, key, x);
  }

  public void del(String key) {
    FiftyOneDegreesTrieV3JNI.MapStringString_del(swigCPtr, this, key);
  }

  public boolean has_key(String key) {
    return FiftyOneDegreesTrieV3JNI.MapStringString_has_key(swigCPtr, this, key);
  }

}
