/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 3.0.12
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package FiftyOneDegreesTrieV3;

public class FiftyOneDegreesTrieV3JNI {
  public final static native long new_MapStringString__SWIG_0();
  public final static native long new_MapStringString__SWIG_1(long jarg1, MapStringString jarg1_);
  public final static native long MapStringString_size(long jarg1, MapStringString jarg1_);
  public final static native boolean MapStringString_empty(long jarg1, MapStringString jarg1_);
  public final static native void MapStringString_clear(long jarg1, MapStringString jarg1_);
  public final static native String MapStringString_get(long jarg1, MapStringString jarg1_, String jarg2);
  public final static native void MapStringString_set(long jarg1, MapStringString jarg1_, String jarg2, String jarg3);
  public final static native void MapStringString_del(long jarg1, MapStringString jarg1_, String jarg2);
  public final static native boolean MapStringString_has_key(long jarg1, MapStringString jarg1_, String jarg2);
  public final static native void delete_MapStringString(long jarg1);
  public final static native long new_VectorString__SWIG_0();
  public final static native long new_VectorString__SWIG_1(long jarg1);
  public final static native long VectorString_size(long jarg1, VectorString jarg1_);
  public final static native long VectorString_capacity(long jarg1, VectorString jarg1_);
  public final static native void VectorString_reserve(long jarg1, VectorString jarg1_, long jarg2);
  public final static native boolean VectorString_isEmpty(long jarg1, VectorString jarg1_);
  public final static native void VectorString_clear(long jarg1, VectorString jarg1_);
  public final static native void VectorString_add(long jarg1, VectorString jarg1_, String jarg2);
  public final static native String VectorString_get(long jarg1, VectorString jarg1_, int jarg2);
  public final static native void VectorString_set(long jarg1, VectorString jarg1_, int jarg2, String jarg3);
  public final static native void delete_VectorString(long jarg1);
  public final static native void delete_Match(long jarg1);
  public final static native long Match_getValues__SWIG_0(long jarg1, Match jarg1_, String jarg2);
  public final static native long Match_getValues__SWIG_1(long jarg1, Match jarg1_, int jarg2);
  public final static native String Match_getValue__SWIG_0(long jarg1, Match jarg1_, String jarg2);
  public final static native String Match_getValue__SWIG_1(long jarg1, Match jarg1_, int jarg2);
  public final static native boolean Match_getValueAsBool__SWIG_0(long jarg1, Match jarg1_, String jarg2);
  public final static native boolean Match_getValueAsBool__SWIG_1(long jarg1, Match jarg1_, int jarg2);
  public final static native int Match_getValueAsInteger__SWIG_0(long jarg1, Match jarg1_, String jarg2);
  public final static native int Match_getValueAsInteger__SWIG_1(long jarg1, Match jarg1_, int jarg2);
  public final static native double Match_getValueAsDouble__SWIG_0(long jarg1, Match jarg1_, String jarg2);
  public final static native double Match_getValueAsDouble__SWIG_1(long jarg1, Match jarg1_, int jarg2);
  public final static native String Match_getDeviceId(long jarg1, Match jarg1_);
  public final static native int Match_getRank(long jarg1, Match jarg1_);
  public final static native int Match_getDifference(long jarg1, Match jarg1_);
  public final static native int Match_getMethod(long jarg1, Match jarg1_);
  public final static native String Match_getUserAgent(long jarg1, Match jarg1_);
  public final static native long new_Provider__SWIG_0(String jarg1);
  public final static native long new_Provider__SWIG_1(String jarg1, String jarg2);
  public final static native long new_Provider__SWIG_2(String jarg1, long jarg2, VectorString jarg2_);
  public final static native void delete_Provider(long jarg1);
  public final static native long Provider_getHttpHeaders(long jarg1, Provider jarg1_);
  public final static native long Provider_getAvailableProperties(long jarg1, Provider jarg1_);
  public final static native String Provider_getDataSetName(long jarg1, Provider jarg1_);
  public final static native String Provider_getDataSetFormat(long jarg1, Provider jarg1_);
  public final static native String Provider_getDataSetPublishedDate(long jarg1, Provider jarg1_);
  public final static native String Provider_getDataSetNextUpdateDate(long jarg1, Provider jarg1_);
  public final static native int Provider_getDataSetSignatureCount(long jarg1, Provider jarg1_);
  public final static native int Provider_getDataSetDeviceCombinations(long jarg1, Provider jarg1_);
  public final static native long Provider_getMatch__SWIG_0(long jarg1, Provider jarg1_, String jarg2);
  public final static native long Provider_getMatchForByteArray(long jarg1, Provider jarg1_, byte[] jarg2);
  public final static native long Provider_getMatch__SWIG_1(long jarg1, Provider jarg1_, long jarg2, MapStringString jarg2_);
  public final static native long Provider_getMatchWithTolerances__SWIG_0(long jarg1, Provider jarg1_, String jarg2, int jarg3, int jarg4);
  public final static native long Provider_getMatchWithTolerances__SWIG_1(long jarg1, Provider jarg1_, long jarg2, MapStringString jarg2_, int jarg3, int jarg4);
  public final static native String Provider_getMatchJson__SWIG_0(long jarg1, Provider jarg1_, String jarg2);
  public final static native String Provider_getMatchJson__SWIG_1(long jarg1, Provider jarg1_, long jarg2, MapStringString jarg2_);
  public final static native void Provider_setDrift(long jarg1, Provider jarg1_, int jarg2);
  public final static native void Provider_setDifference(long jarg1, Provider jarg1_, int jarg2);
  public final static native void Provider_reloadFromFile(long jarg1, Provider jarg1_);
  public final static native void Provider_reloadFromMemory(long jarg1, Provider jarg1_, long jarg2, int jarg3);
  public final static native boolean Provider_getIsThreadSafe(long jarg1, Provider jarg1_);
  public final static native long new_Provider__SWIG_3(String jarg1, String jarg2, boolean jarg3);
}
